@@ -40,7 +40,7 @@ import java.util.jar.JarFile;
 
 /**
  * @author David Blevins
- * @version $Rev: 634087 $ $Date: 2008-03-06 01:05:23 +0100 (Do, 06. Mär 2008) $
+ * @version $Rev: 936567 $ $Date: 2010-04-22 01:41:32 +0200 (jeu. 22 avril 2010) $
  */
 public class ResourceFinder {
 
@@ -668,7 +668,7 @@ public class ResourceFinder {
 
         URL resource = getResource(fulluri);
         if (resource == null) {
-            throw new IOException("Could not find command in : " + fulluri);
+            throw new IOException("Could not find resource: " + fulluri);
         }
 
         return loadProperties(resource);
@@ -860,7 +860,7 @@ public class ResourceFinder {
             for (File file : files) {
                 if (!file.isDirectory()) {
                     String name = file.getName();
-                    URL url = file.toURL();
+                    URL url = file.toURI().toURL();
                     resources.put(name, url);
                 }
             }
@@ -961,8 +961,8 @@ public class ResourceFinder {
             URL currentUrl = search[i];
             if (currentUrl == null) {
                 continue;
-            }
-            JarFile jarFile = null;
+            }            
+
             try {
                 String protocol = currentUrl.getProtocol();
                 if (protocol.equals("jar")) {
@@ -972,8 +972,10 @@ public class ResourceFinder {
                     * entry doesn't exist.
                     */
                     URL jarURL = ((JarURLConnection) currentUrl.openConnection()).getJarFileURL();
+                    JarFile jarFile;
+                    JarURLConnection juc;
                     try {
-                        JarURLConnection juc = (JarURLConnection) new URL("jar", "", jarURL.toExternalForm() + "!/").openConnection();
+                        juc = (JarURLConnection) new URL("jar", "", jarURL.toExternalForm() + "!/").openConnection();
                         jarFile = juc.getJarFile();
                     } catch (IOException e) {
                         // Don't look for this jar file again
@@ -981,29 +983,41 @@ public class ResourceFinder {
                         throw e;
                     }
 
-                    String entryName;
-                    if (currentUrl.getFile().endsWith("!/")) {
-                        entryName = resourceName;
-                    } else {
-                        String file = currentUrl.getFile();
-                        int sepIdx = file.lastIndexOf("!/");
-                        if (sepIdx == -1) {
-                            // Invalid URL, don't look here again
-                            search[i] = null;
-                            continue;
+                    try {
+                        juc = (JarURLConnection) new URL("jar", "", jarURL.toExternalForm() + "!/").openConnection();                        
+                        jarFile = juc.getJarFile();
+                        String entryName;
+                        if (currentUrl.getFile().endsWith("!/")) {
+                            entryName = resourceName;
+                        } else {
+                            String file = currentUrl.getFile();
+                            int sepIdx = file.lastIndexOf("!/");
+                            if (sepIdx == -1) {
+                                // Invalid URL, don't look here again
+                                search[i] = null;
+                                continue;
+                            }
+                            sepIdx += 2;
+                            StringBuffer sb = new StringBuffer(file.length() - sepIdx + resourceName.length());
+                            sb.append(file.substring(sepIdx));
+                            sb.append(resourceName);
+                            entryName = sb.toString();
+                        }
+                        if (entryName.equals("META-INF/") && jarFile.getEntry("META-INF/MANIFEST.MF") != null) {
+                            return targetURL(currentUrl, "META-INF/MANIFEST.MF");
+                        }
+                        if (jarFile.getEntry(entryName) != null) {
+                            return targetURL(currentUrl, resourceName);
+                        }
+                    } finally {
+                        if (!juc.getUseCaches()) {
+                            try {
+                                jarFile.close();
+                            } catch (Exception e) {
+                            }
                         }
-                        sepIdx += 2;
-                        StringBuffer sb = new StringBuffer(file.length() - sepIdx + resourceName.length());
-                        sb.append(file.substring(sepIdx));
-                        sb.append(resourceName);
-                        entryName = sb.toString();
-                    }
-                    if (entryName.equals("META-INF/") && jarFile.getEntry("META-INF/MANIFEST.MF") != null){
-                        return targetURL(currentUrl, "META-INF/MANIFEST.MF");
-                    }
-                    if (jarFile.getEntry(entryName) != null) {
-                        return targetURL(currentUrl, resourceName);
                     }
+                    
                 } else if (protocol.equals("file")) {
                     String baseFile = currentUrl.getFile();
                     String host = currentUrl.getHost();
