@@ -24,4 +24,7 @@ import org.apache.xbean.naming.global.GlobalContextManager;
  * @version $Rev: 355877 $ $Date: 2005-12-10 18:48:27 -0800 (Sat, 10 Dec 2005) $
  */
 public class javaURLContextFactory extends GlobalContextManager {
+    public javaURLContextFactory() {
+        System.out.println(getClass().getName());
+    }
 }
